/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: MyTraceMessageProcessor.java 17678 2009-06-16 09:17:25Z alitokmen $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.samples.camel.example.trace;

import org.apache.camel.Exchange;
import org.apache.camel.Processor;
import org.apache.camel.processor.interceptor.DefaultTraceEventMessage;
import org.apache.camel.processor.interceptor.TraceEventMessage;

/**
 * Processor Class to process the TraceEventMessage. it is used to constructs a
 * message from the TraceEventMessage and replaces it in the IN body.
 * 
 * @author chahinem
 */
class MyTraceMessageProcessor implements Processor {

    public void process(final Exchange exchange) throws Exception {

        // here we can transform the message how we like want it
        TraceEventMessage msg = exchange.getIn().getBody(DefaultTraceEventMessage.class);

        StringBuilder sb = new StringBuilder();
        String from = "";
        String to = "";
        String result = "";

        if (msg.getPreviousNode() != null) {
            from = msg.getPreviousNode();
        } else if (msg.getFromEndpointUri() != null) {
            from = msg.getFromEndpointUri();
        }
        to = msg.getToNode();
        result = from + " --> " + to.trim();

        sb.append(" - ").append(msg.getTimestamp());
        sb.append(" ").append(result);
        sb.append(", Pattern:").append(msg.getExchangePattern());
        sb.append(", Properties:").append(msg.getProperties());
        sb.append(", Headers:").append(msg.getHeaders());
        sb.append(", BodyType:").append(msg.getBodyType());
        sb.append(", Body:").append(msg.getBody());
        // sb.append(", OutHeaders:").append(msg.get);
        if (msg.getOutBody() != null) {
            sb.append(", OutBodyType:").append(msg.getOutBodyType());
            sb.append(", OutBody:").append(msg.getOutBody());
        }
        if (msg.getCausedByException() != null) {
            sb.append(", Exception:").append(msg.getCausedByException());
        }
        exchange.getIn().setBody(sb.toString());
    }
}
